@@ -5,6 +5,7 @@ use Carp 'croak';
 use DBI;
 use Mojo::Pg::Database;
 use Mojo::Pg::Migrations;
+use Mojo::Pg::PubSub;
 use Mojo::URL;
 use Scalar::Util 'weaken';
 
@@ -16,16 +17,27 @@ has migrations      => sub {
   return $migrations;
 };
 has options => sub {
-  {AutoCommit => 1, PrintError => 0, RaiseError => 1, pg_server_prepare => 0};
+  {
+    AutoCommit          => 1,
+    AutoInactiveDestroy => 1,
+    PrintError          => 0,
+    RaiseError          => 1,
+    pg_server_prepare   => 0
+  };
 };
 has [qw(password username)] => '';
+has pubsub => sub {
+  my $pubsub = Mojo::Pg::PubSub->new(pg => shift);
+  weaken $pubsub->{pg};
+  return $pubsub;
+};
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 sub db {
   my $self = shift;
 
-  # Fork safety
+  # Fork-safety
   delete @$self{qw(pid queue)} unless ($self->{pid} //= $$) eq $$;
 
   my ($dbh, $handle) = @{$self->_dequeue};
@@ -137,13 +149,17 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
     }
   )->wait;
 
-  # Listen for notifications non-blocking
-  $db->on(notification => sub {
-    my ($db, $name, $pid, $payload) = @_;
-    say "$name: $payload";
-    $db->notify('bar', $payload) if $name eq 'foo';
+  # Send and receive notifications non-blocking
+  $pg->pubsub->listen(foo => sub {
+    my ($pubsub, $payload) = @_;
+    say "foo: $payload";
+    $pubsub->notify(bar => $payload);
   });
-  $db->listen('foo');
+  $pg->pubsub->listen(bar => sub {
+    my ($pubsub, $payload) = @_;
+    say "bar: $payload";
+  });
+  $pg->pubsub->notify(foo => 'PostgreSQL rocks!');
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
 =head1 DESCRIPTION
@@ -242,8 +258,9 @@ easily.
   my $options = $pg->options;
   $pg         = $pg->options({AutoCommit => 1});
 
-Options for database handles, defaults to activating C<AutoCommit> as well as
-C<RaiseError> and deactivating C<PrintError> as well as C<pg_server_prepare>.
+Options for database handles, defaults to activating C<AutoCommit>,
+C<AutoInactiveDestroy> as well as C<RaiseError> and deactivating C<PrintError>
+as well as C<pg_server_prepare>.
 
 =head2 password
 
@@ -252,6 +269,24 @@ C<RaiseError> and deactivating C<PrintError> as well as C<pg_server_prepare>.
 
 Database password, defaults to an empty string.
 
+=head2 pubsub
+
+  my $pubsub = $pg->pubsub;
+  $pg        = $pg->pubsub(Mojo::Pg::PubSub->new);
+
+L<Mojo::Pg::PubSub> object you can use to send and receive notifications very
+efficiently, by sharing a single database connection with many consumers. Note
+that this attribute is EXPERIMENTAL and might change without warning!
+
+  # Subscribe to a channel
+  $pg->pubsub->listen(news => sub {
+    my ($pubsub, $payload) = @_;
+    say "Received: $payload";
+  });
+
+  # Notify a channel
+  $pg->pubsub->notify(news => 'PostgreSQL rocks!');
+
 =head2 username
 
   my $username = $pg->username;
